@@ -21,8 +21,6 @@
  *           Bell Labs Innovations for Lucent Technologies
  *           mmclennan@lucent.com
  *           http://www.tcltk.com/itcl
- *
- *     RCS:  $Id: itcl_objects.c,v 1.13 2003/12/23 03:11:04 davygrvy Exp $
  * ========================================================================
  *           Copyright (c) 1993-1998  Lucent Technologies, Inc.
  * ------------------------------------------------------------------------
@@ -102,14 +100,14 @@ Itcl_CreateObject(interp, name, cdefn, objc, objv, roPtr)
      *  only in the current namespace context.  Otherwise, we might
      *  find a global command, but that wouldn't be clobbered!
      */
-    cmd = Tcl_FindCommand(interp, (CONST84 char *)name,
+    cmd = Tcl_FindCommand(interp, name,
 	(Tcl_Namespace*)NULL, TCL_NAMESPACE_ONLY);
 
     if (cmd != NULL && !Itcl_IsStub(cmd)) {
-        Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
-            "command \"", name, "\" already exists in namespace \"",
-            Tcl_GetCurrentNamespace(interp)->fullName, "\"",
-            (char*)NULL);
+        Tcl_AppendResult(interp,
+		"command \"", name, "\" already exists in namespace \"",
+		Tcl_GetCurrentNamespace(interp)->fullName, "\"",
+		(char*) NULL);
         return TCL_ERROR;
     }
 
@@ -122,10 +120,10 @@ Itcl_CreateObject(interp, name, cdefn, objc, objv, roPtr)
         parentNs = Itcl_FindClassNamespace(interp, head);
 
         if (!parentNs) {
-            Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
-                "namespace \"", head, "\" not found in context \"",
-                Tcl_GetCurrentNamespace(interp)->fullName, "\"",
-                (char*)NULL);
+            Tcl_AppendResult(interp,
+		    "namespace \"", head, "\" not found in context \"",
+		    Tcl_GetCurrentNamespace(interp)->fullName, "\"",
+		    (char *) NULL);
             Tcl_DStringFree(&buffer);
             return TCL_ERROR;
         }
@@ -376,9 +374,9 @@ Itcl_DestructObject(interp, contextObj, flags)
      */
     if (contextObj->destructed) {
         if ((flags & ITCL_IGNORE_ERRS) == 0) {
-            Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
-                "can't delete an object while it is being destructed",
-                (char*)NULL);
+            Tcl_AppendResult(interp,
+		    "can't delete an object while it is being destructed",
+		    (char*)NULL);
             return TCL_ERROR;
         }
         return TCL_OK;
@@ -440,7 +438,7 @@ ItclDestructBase(interp, contextObj, contextClass, flags)
      *  Look for a destructor in this class, and if found,
      *  invoke it.
      */
-    if (!Tcl_FindHashEntry(contextObj->destructed, contextClass->name)) {
+    if (!Tcl_FindHashEntry(contextObj->destructed, contextClass->fullname)) {
 
         result = Itcl_InvokeMethodIfExists(interp, "destructor",
             contextClass, contextObj, 0, (Tcl_Obj* CONST*)NULL);
@@ -605,12 +603,12 @@ Itcl_HandleInstance(clientData, interp, objc, objv)
     ItclMemberFunc *mfunc;
     ItclObjectInfo *info;
     ItclContext context;
-    CallFrame *framePtr;
+    ItclCallFrame *framePtr;
 
     if (objc < 2) {
-        Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
-            "wrong # args: should be one of...",
-            (char*)NULL);
+        Tcl_AppendResult(interp,
+		"wrong # args: should be one of...",
+		(char *) NULL);
         ItclReportObjectUsage(interp, contextObj);
         return TCL_ERROR;
     }
@@ -641,9 +639,9 @@ Itcl_HandleInstance(clientData, interp, objc, objv)
     }
 
     if ( !mfunc && (*token != 'i' || strcmp(token,"info") != 0) ) {
-        Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
-            "bad option \"", token, "\": should be one of...",
-            (char*)NULL);
+        Tcl_AppendResult(interp,
+		"bad option \"", token, "\": should be one of...",
+		(char*)NULL);
         ItclReportObjectUsage(interp, contextObj);
         return TCL_ERROR;
     }
@@ -668,7 +666,7 @@ Itcl_HandleInstance(clientData, interp, objc, objv)
         return TCL_ERROR;
     }
 
-    framePtr = &context.frame;
+    framePtr = (ItclCallFrame *) &context.frame;
     Itcl_PushStack((ClientData)framePtr, &info->transparentFrames);
 
     /* Bug 227824
@@ -719,9 +717,9 @@ Itcl_GetInstanceVar(interp, name, contextObj, contextClass)
      */
     if (contextObj == NULL) {
         Tcl_ResetResult(interp);
-        Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
-            "cannot access object-specific info without an object context",
-            (char*)NULL);
+        Tcl_SetResult(interp,
+		"cannot access object-specific info without an object context",
+		TCL_STATIC);
         return NULL;
     }
 
@@ -735,7 +733,7 @@ Itcl_GetInstanceVar(interp, name, contextObj, contextClass)
         return NULL;
     }
 
-    val = Tcl_GetVar2(interp, (CONST84 char *)name, (char*)NULL,
+    val = Tcl_GetVar2(interp, name, (char*)NULL,
 	    TCL_LEAVE_ERR_MSG);
     Itcl_PopContext(interp, &context);
 
@@ -872,7 +870,7 @@ ItclTraceThisVar(cdata, interp, name1, name2, flags)
         }
 
         objName = Tcl_GetString(objPtr);
-        Tcl_SetVar(interp, (CONST84 char *)name1, objName, 0);
+        Tcl_SetVar(interp, name1, objName, 0);
 
         Tcl_DecrRefCount(objPtr);
         return NULL;
@@ -1072,22 +1070,26 @@ ItclCreateObjVar(interp, vdefn, contextObj)
     ItclContext context;
 
     varPtr = _TclNewVar();
-    varPtr->name = vdefn->member->name;
-    varPtr->nsPtr = (Namespace*)vdefn->member->classDefn->namesp;
+#if ITCL_TCL_PRE_8_5
+    if (itclOldRuntime) {    
+	varPtr->name = vdefn->member->name;
+	varPtr->nsPtr = (Namespace*)vdefn->member->classDefn->namesp;
 
-    /*
-     *  NOTE:  Tcl reports a "dangling upvar" error for variables
-     *         with a null "hPtr" field.  Put something non-zero
-     *         in here to keep Tcl_SetVar2() happy.  The only time
-     *         this field is really used is it remove a variable
-     *         from the hash table that contains it in CleanupVar,
-     *         but since these variables are protected by their
-     *         higher refCount, they will not be deleted by CleanupVar
-     *         anyway.  These variables are unset and removed in
-     *         ItclFreeObject().
-     */
-    varPtr->hPtr = (Tcl_HashEntry*)0x1;
-    varPtr->refCount = 1;  /* protect from being deleted */
+	/*
+	 *  NOTE:  Tcl reports a "dangling upvar" error for variables
+	 *         with a null "hPtr" field.  Put something non-zero
+	 *         in here to keep Tcl_SetVar2() happy.  The only time
+	 *         this field is really used is it remove a variable
+	 *         from the hash table that contains it in CleanupVar,
+	 *         but since these variables are protected by their
+	 *         higher refCount, they will not be deleted by CleanupVar
+	 *         anyway.  These variables are unset and removed in
+	 *         ItclFreeObject().
+	 */
+	varPtr->hPtr = (Tcl_HashEntry*)0x1;
+	ItclVarRefCount(varPtr) = 1;  /* protect from being deleted */
+    }
+#endif
 
     /*
      *  Install the new variable in the object's data array.
@@ -1150,7 +1152,7 @@ Itcl_ScopedVarResolver(interp, name, contextNs, flags, rPtr)
     Tcl_Var *rPtr;             /* returns: resolved variable */
 {
     int namec;
-    char **namev;
+    CONST char **namev;
     Tcl_Interp *errs;
     Tcl_CmdInfo cmdInfo;
     ItclObject *contextObj;
@@ -1175,16 +1177,16 @@ Itcl_ScopedVarResolver(interp, name, contextNs, flags, rPtr)
         errs = NULL;
     }
 
-    if (Tcl_SplitList(errs, (CONST84 char *)name, &namec, &namev)
+    if (Tcl_SplitList(errs, name, &namec, &namev)
 	    != TCL_OK) {
         return TCL_ERROR;
     }
     if (namec != 3) {
         if (errs) {
-            Tcl_AppendStringsToObj(Tcl_GetObjResult(errs),
-                "scoped variable \"", name, "\" is malformed: ",
-                "should be: @itcl object variable",
-                (char*)NULL);
+            Tcl_AppendResult(errs,
+		    "scoped variable \"", name, "\" is malformed: ",
+		    "should be: @itcl object variable",
+		    (char*) NULL);
         }
         ckfree((char*)namev);
         return TCL_ERROR;
@@ -1196,7 +1198,7 @@ Itcl_ScopedVarResolver(interp, name, contextNs, flags, rPtr)
      */
     if (!Tcl_GetCommandInfo(interp, namev[1], &cmdInfo)) {
         if (errs) {
-            Tcl_AppendStringsToObj(Tcl_GetObjResult(errs),
+            Tcl_AppendResult(errs,
                 "can't resolve scoped variable \"", name, "\": ",
                 "can't find object ", namev[1],
                 (char*)NULL);
@@ -1213,7 +1215,7 @@ Itcl_ScopedVarResolver(interp, name, contextNs, flags, rPtr)
     entry = Tcl_FindHashEntry(&contextObj->classDefn->resolveVars, namev[2]);
     if (!entry) {
         if (errs) {
-            Tcl_AppendStringsToObj(Tcl_GetObjResult(errs),
+            Tcl_AppendResult(errs,
                 "can't resolve scoped variable \"", name, "\": ",
                 "no such data member ", namev[2],
                 (char*)NULL);
